Stan Math Library: stan/math/rev/mat/fun/Eigen_NumTraits.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
Eigen_NumTraits.hpp File Reference
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/rev/core/gevv_vvv_vari.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <limits>`

Go to the source code of this file.

## Classes
struct | Eigen::NumTraits< stan::math::var >
| Numerical traits template override for Eigen for automatic gradient variables. More...
struct | Eigen::internal::significant_decimals_default_impl< stan::math::var, false >
| Implemented this for printing to stream. More...
struct | Eigen::internal::scalar_product_traits< stan::math::var, double >
| Scalar product traits override for Eigen for automatic gradient variables. More...
struct | Eigen::internal::scalar_product_traits< double, stan::math::var >
| Scalar product traits override for Eigen for automatic gradient variables. More...
struct | Eigen::internal::general_matrix_vector_product< Index, stan::math::var, ColMajor, ConjugateLhs, stan::math::var, ConjugateRhs >
| Override matrix-vector and matrix-matrix products to use more efficient implementation. More...
struct | Eigen::internal::general_matrix_vector_product< Index, stan::math::var, RowMajor, ConjugateLhs, stan::math::var, ConjugateRhs >
struct | Eigen::internal::general_matrix_matrix_product< Index, stan::math::var, LhsStorageOrder, ConjugateLhs, stan::math::var, RhsStorageOrder, ConjugateRhs, ColMajor >

## Namespaces
| Eigen
| (Expert) Numerical traits for algorithmic differentiation variables.
| Eigen::internal
| (Expert) Product traits for algorithmic differentiation variables.

[ Stan Home Page ] © 2011–2016, Stan Development Team.